bands_gradient_mesh — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# bands_gradient_mesh

property ElectronicBandStructure.bands_gradient_mesh

  Bands gradient mesh is a numpy array that stores each band gradient in a mesh grid. Shape = [3,n_bands,n_kx,n_ky,n_kz], where the first dimension represents d/dx,d/dy,d/dz

  Returns:

    np.ndarray – Bands fradient mesh is a numpy array that stores each band gradient in a mesh grid. Shape = [n_kx,n_ky,n_kz,3,n_bands], where the first dimension represents d/dx,d/dy,d/dz